@@ -1,4 +1,4 @@
 library(testthat)
 library(readbitmap)
 
-test_package("readbitmap")
\ No newline at end of file
+test_check("readbitmap")
